==> kap-0.1.0.tar.gz: kap-0.1.0/kap/medialibrarydialogue.py <==
#!/usr/bin/env python
#******************************************************************************
#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
#****                                                                      ****
#**** This program is free software: you can redistribute it and/or modify ****
#**** it under the terms of the GNU General Public License as published by ****
#**** the Free Software Foundation, either version 3 of the License, or    ****
#**** (at your option) any later version.                                  ****
#****                                                                      ****
#**** This program is distributed in the hope that it will be useful,      ****
#**** but WITHOUT ANY WARRANTY; without even the implied warranty of       ****
#**** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        ****
#**** GNU General Public License for more details.                         ****
#****                                                                      ****
#**** You should have received a copy of the GNU General Public License    ****
#**** along with this program.  If not, see <http://www.gnu.org/licenses/> ****
#******************************************************************************

import wx


class MediaLibraryDialogue(wx.Dialog):
    """ A dialogue to configure the media library """

    """
     ATTRIBUTES
    """
    # Indicates if the a setting has changed
    blIsSettingsDirty = False

    """
     Event IDs
    """
    # Used to signal to add a new directory
    __ID_ADD_DIRECTORY = wx.NewId()
    # Used to signal to remove a currently listed directory.
    __ID_REMOVE_DIRECTORY = wx.NewId()

    def __init__(self, parent, directoryPaths=[]):
        """ Dialogue constructor.

         wx.Window parent: is the parent window to the dialogue
         list[string] directoryPaths: the paths to each directory to search \
           for media.
        """
        wx.Dialog.__init__(self, parent, wx.NewId(), "Media Library")
        self.__createControls(directoryPaths)
        self.__bindEvents()
        self.__doLayout()

    def mediaLibraryPaths(self):
        """ Accessor to the paths the user selected

         return list[string]: a list of all the paths the user selected.
        """
        return self.__lstBxDirectories.GetItems()

    def __createControls(self, directoryPaths):
        """ Creates all the user controls for the dialogue.

         list[string] directoryPaths: are the paths to each directory to
           search for media.
        """
        self.__pnlMain = wx.Panel(self)

        # Create Directory Listing
        self.__lstBxDirectories = wx.ListBox(self.__pnlMain, -1, \
            wx.DefaultPosition, wx.DefaultSize, "", wx.LB_SINGLE, \
            wx.DefaultValidator, "Directory List Box")
        for directoryPath in directoryPaths:
            self.__lstBxDirectories.Append(directoryPath)
        self.__bttnAddDirectory = wx.Button(self.__pnlMain, \
            self.__ID_ADD_DIRECTORY, "Add Directory")
        self.__bttnRemoveDirectory = wx.Button(self.__pnlMain, \
            self.__ID_REMOVE_DIRECTORY, "Remove Directory")

        # Create interface direction buttons
        self.__bttnCreateLibrary = wx.Button(self.__pnlMain, wx.ID_OK, \
            "Create Library")
        self.__bttnClose = wx.Button(self.__pnlMain, wx.ID_CANCEL, "Close")

    def __bindEvents(self):
        """ Binds the controls to their corresponding events. """
        wx.EVT_BUTTON(self, self.__ID_ADD_DIRECTORY, \
            self.__onAddDirectory)
        wx.EVT_BUTTON(self, self.__ID_REMOVE_DIRECTORY, \
            self.__onRemoveDirectory)
        wx.EVT_BUTTON(self, wx.ID_OK, self.__onCreateLibrary)
        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.__onClose)
        wx.EVT_CLOSE(self, self.__onClose)

    def __doLayout(self):
        """ Places the controls in a defined layout. """

        # Directory Listing Layout
        self.__bxSzrDirectories = wx.BoxSizer(wx.HORIZONTAL)
        self.__bxSzrDirectories.Add(self.__lstBxDirectories, 1, \
            wx.EXPAND | wx.ALL, 3)
        self.__bxSzrDirectoryButtons = wx.BoxSizer(wx.VERTICAL)
        self.__bxSzrDirectoryButtons.Add(self.__bttnAddDirectory, 0, wx.ALL)
        self.__bxSzrDirectoryButtons.AddSpacer(5)
        self.__bxSzrDirectoryButtons.Add(self.__bttnRemoveDirectory, 0, wx.ALL)
        self.__bxSzrDirectories.Add(self.__bxSzrDirectoryButtons, 0, wx.ALL)

        # Dialogue Buttons
        self.__stdDlgBttnSzrButtons = wx.StdDialogButtonSizer()
        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnCreateLibrary)
        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnClose)
        self.__stdDlgBttnSzrButtons.Realize()

        # Create Interface
        self.__bxSzrInterface = wx.BoxSizer(wx.VERTICAL)
        self.__bxSzrInterface.AddSpacer(15)
        self.__bxSzrInterface.Add(self.__bxSzrDirectories, 1, wx.EXPAND | \
            wx.ALL)
        self.__bxSzrInterface.AddSpacer(5)
        self.__bxSzrInterface.Add(self.__stdDlgBttnSzrButtons, 0, wx.ALL)
        self.__bxSzrInterface.AddSpacer(15)

        self.__pnlMain.SetSizer(self.__bxSzrInterface)

    def __onAddDirectory(self, event):
        """ Allows a user to add a directory to the search paths.

         A dialogue for the user to select a directory to add to the media
           search list. If a directory is added, the settings are marked as
           being dirty.
         wx.Event event: is the event object (Not Used)
        """
        drdlgAddDirectory = wx.DirDialog(self, "Choose a directory", "", \
            wx.DD_DIR_MUST_EXIST)
        if (drdlgAddDirectory.ShowModal() == wx.ID_OK):
            path = drdlgAddDirectory.GetPath()
            self.__lstBxDirectories.Append(path)
            self.blIsSettingsDirty = True

    def __onRemoveDirectory(self, event):
        """ Allows a user to remove a directory from the search paths.

         Removes the selected path from the directory listing. Marks the
           settings as being dirty.
         wx.Event event: is the event object (Not Used)
        """
        index = self.__lstBxDirectories.GetSelection()
        self.__lstBxDirectories.Delete(index)
        self.blIsSettingsDirty = True

    def __onCreateLibrary(self, event):
        """ User wants to create the library.

         Creates a new library database, by marking the settings as dirty.
         wx.Event event: is the event object (Not Used)
        """
        self.blIsSettingsDirty = True
        self.Show(False)
        self.Destroy()

    def __onClose(self, event):
        """ Closes the dialogue.

         Handles the closing of the dialogue. If the settings have been marked
           as being dirty, the user is asked to confirm that they wish to
           discard all of their changes.
         wx.Event event: is the event object (Not Used)
        """
        if self.blIsSettingsDirty:
            answer = wx.MessageBox("Media library paths have changed!", \
                "Confirm Close", wx.YES_NO | wx.ICON_QUESTION)
            if answer == wx.YES:
                self.blIsSettingsDirty = False
            else:
                return
        self.Show(False)
        self.Destroy()

==> kap-0.2.0.tar.gz: kap-0.2.0/kap/medialibrarydialogue.py <==
#!/usr/bin/env python
#******************************************************************************
#**** Copyright (C) 2009  John Schneiderman <JohnMS@member.fsf.org>        ****
#****                                                                      ****
#**** This program is free software: you can redistribute it and/or modify ****
#**** it under the terms of the GNU General Public License as published by ****
#**** the Free Software Foundation, either version 3 of the License, or    ****
#**** (at your option) any later version.                                  ****
#****                                                                      ****
#**** This program is distributed in the hope that it will be useful,      ****
#**** but WITHOUT ANY WARRANTY; without even the implied warranty of       ****
#**** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        ****
#**** GNU General Public License for more details.                         ****
#****                                                                      ****
#**** You should have received a copy of the GNU General Public License    ****
#**** along with this program.  If not, see <http://www.gnu.org/licenses/> ****
#******************************************************************************

"""
 IMPORTS
"""
import wx


class MediaLibraryDialogue(wx.Dialog):
    """ A dialogue to configure the media library """

    """
     ATTRIBUTES
    """
    # Indicates if the a setting has changed
    blIsSettingsDirty = False

    """
     Event IDs
    """
    # Used to signal to add a new directory
    __ID_ADD_DIRECTORY = wx.NewId()
    # Used to signal to remove a currently listed directory.
    __ID_REMOVE_DIRECTORY = wx.NewId()

    def __init__(self, parent, directoryPaths=[]):
        """ Dialogue constructor.

         wx.Window parent: is the parent window to the dialogue
         list[string] directoryPaths: the paths to each directory to search \
           for media.
        """
        wx.Dialog.__init__(self, parent, wx.NewId(), "Media Library")
        self.__createControls(directoryPaths)
        self.__bindEvents()
        self.__doLayout()

    def mediaLibraryPaths(self):
        """ Accessor to the paths the user selected

         return list[string]: a list of all the paths the user selected.
        """
        return self.__lstBxDirectories.GetItems()

    def __createControls(self, directoryPaths):
        """ Creates all the user controls for the dialogue.

         list[string] directoryPaths: are the paths to each directory to
           search for media.
        """
        # Create Directory Listing
        self.__lstBxDirectories = wx.ListBox(self, -1, \
            wx.DefaultPosition, wx.DefaultSize, "", wx.LB_SINGLE, \
            wx.DefaultValidator, "Directory List Box")
        for directoryPath in directoryPaths:
            self.__lstBxDirectories.Append(directoryPath)
        self.__bttnAddDirectory = wx.Button(self, \
            self.__ID_ADD_DIRECTORY, "Add Directory")
        self.__bttnRemoveDirectory = wx.Button(self, \
            self.__ID_REMOVE_DIRECTORY, "Remove Directory")

        # Create interface direction buttons
        self.__bttnCreateLibrary = wx.Button(self, wx.ID_OK, \
            "Create Library")
        self.__bttnClose = wx.Button(self, wx.ID_CANCEL, "Close")

    def __bindEvents(self):
        """ Binds the controls to their corresponding events. """
        wx.EVT_BUTTON(self, self.__ID_ADD_DIRECTORY, \
            self.__onAddDirectory)
        wx.EVT_BUTTON(self, self.__ID_REMOVE_DIRECTORY, \
            self.__onRemoveDirectory)
        wx.EVT_BUTTON(self, wx.ID_OK, self.__onCreateLibrary)
        wx.EVT_BUTTON(self, wx.ID_CANCEL, self.__onClose)
        wx.EVT_CLOSE(self, self.__onClose)

    def __doLayout(self):
        """ Places the controls in a defined layout. """

        # Directory Listing Layout
        self.__bxSzrDirectories = wx.BoxSizer(wx.HORIZONTAL)
        self.__bxSzrDirectories.Add(self.__lstBxDirectories, 1, \
            wx.EXPAND | wx.ALL, 3)
        self.__bxSzrDirectoryButtons = wx.BoxSizer(wx.VERTICAL)
        self.__bxSzrDirectoryButtons.Add(self.__bttnAddDirectory, 0, wx.ALL)
        self.__bxSzrDirectoryButtons.AddSpacer(5)
        self.__bxSzrDirectoryButtons.Add(self.__bttnRemoveDirectory, 0, wx.ALL)
        self.__bxSzrDirectories.Add(self.__bxSzrDirectoryButtons, 0, wx.ALL)

        # Dialogue Buttons
        self.__stdDlgBttnSzrButtons = wx.StdDialogButtonSizer()
        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnCreateLibrary)
        self.__stdDlgBttnSzrButtons.AddButton(self.__bttnClose)
        self.__stdDlgBttnSzrButtons.Realize()

        # Create Interface
        self.__bxSzrInterface = wx.BoxSizer(wx.VERTICAL)
        self.__bxSzrInterface.AddSpacer(15)
        self.__bxSzrInterface.Add(self.__bxSzrDirectories, 1, wx.EXPAND | \
            wx.ALL)
        self.__bxSzrInterface.AddSpacer(5)
        self.__bxSzrInterface.Add(self.__stdDlgBttnSzrButtons, 0, wx.ALL)
        self.__bxSzrInterface.AddSpacer(15)
        self.SetSizer(self.__bxSzrInterface)

    def __onAddDirectory(self, event):
        """ Allows a user to add a directory to the search paths.

         A dialogue for the user to select a directory to add to the media
           search list. If a directory is added, the settings are marked as
           being dirty.
         wx.Event event: is the event object (Not Used)
        """
        drdlgAddDirectory = wx.DirDialog(self, "Choose a directory", "", \
            wx.DD_DIR_MUST_EXIST)
        if (drdlgAddDirectory.ShowModal() == wx.ID_OK):
            path = drdlgAddDirectory.GetPath()
            self.__lstBxDirectories.Append(path)
            self.blIsSettingsDirty = True

    def __onRemoveDirectory(self, event):
        """ Allows a user to remove a directory from the search paths.

         Removes the selected path from the directory listing. Marks the
           settings as being dirty.
         wx.Event event: is the event object (Not Used)
        """
        index = self.__lstBxDirectories.GetSelection()
        self.__lstBxDirectories.Delete(index)
        self.blIsSettingsDirty = True

    def __onCreateLibrary(self, event):
        """ User wants to create the library.

         Creates a new library database, by marking the settings as dirty.
         wx.Event event: is the event object (Not Used)
        """
        self.blIsSettingsDirty = True
        self.Show(False)
        self.Destroy()

    def __onClose(self, event):
        """ Closes the dialogue.

         Handles the closing of the dialogue. If the settings have been marked
           as being dirty, the user is asked to confirm that they wish to
           discard all of their changes.
         wx.Event event: is the event object (Not Used)
        """
        if self.blIsSettingsDirty:
            answer = wx.MessageBox("Media library paths have changed!", \
                "Confirm Close", wx.YES_NO | wx.ICON_QUESTION)
            if answer == wx.YES:
                self.blIsSettingsDirty = False
            else:
                return
        self.Show(False)
        self.Destroy()
